@@ -111,7 +111,7 @@ typedef struct
     int32_t *ctts_sample_offset;
 
     /* esde */
-    uint8_t *decoderConfig;
+    int8_t *decoderConfig;
     int32_t decoderConfigLen;
 
     uint32_t maxBitrate;
@@ -165,7 +165,7 @@ int32_t mp4ff_find_sample(const mp4ff_t *f, const int32_t track, const int64_t o
 int32_t mp4ff_find_sample_use_offsets(const mp4ff_t *f, const int32_t track, const int64_t offset,int32_t * toskip);
 
 int32_t mp4ff_read_sample(mp4ff_t *f, const int track, const int sample,
-                          unsigned char **audio_buffer,  unsigned int *bytes);
+                          int8_t **audio_buffer,  unsigned int *bytes);
 
 int32_t mp4ff_read_sample_v2(mp4ff_t *f, const int track, const int sample,unsigned char *buffer);//returns 0 on error, number of bytes read on success, use mp4ff_read_sample_getsize() to check buffer size needed
 int32_t mp4ff_read_sample_getsize(mp4ff_t *f, const int track, const int sample);//returns 0 on error, buffer size needed for mp4ff_read_sample_v2() on success
